<?php
/**
 * Namespace names. NS_PROJECT is always set to $wgMetaNamespace after the
 * settings are loaded, it will be ignored even if you specify it here.
 *
 * NS_PROJECT_TALK will be set to $wgMetaNamespaceTalk if that variable is
 * set, otherwise the string specified here will be used. The string may
 * contain "$1", which will be replaced by the name of NS_PROJECT. It may
 * also contain a grammatical transformation, e.g.
 *
 *     NS_PROJECT_TALK => 'Keskustelu_{{grammar:elative|$1}}'
 *
 * Only one grammatical transform may be specified in the string. For
 * performance reasons, this transformation is done locally by the language
 * module rather than by the full wikitext parser. As a result, no other
 * parser features are available.
 */
$namespaceNames = [
	NS_MEDIA            => 'M3a',
	NS_SPECIAL          => 'S5l',
	NS_MAIN             => '',
	NS_TALK             => 'T2k',
	NS_USER             => 'U2r',
	NS_USER_TALK        => 'U2r_t2k',
	# NS_PROJECT set by $wgMetaNamespace
	NS_PROJECT_TALK     => '$1_t2k',
	NS_FILE             => 'F2e',
	NS_FILE_TALK        => 'F2e_t2k',
	NS_MEDIAWIKI        => 'M7i',
	NS_MEDIAWIKI_TALK   => 'M7i_t2k',
	NS_TEMPLATE         => 'T6e',
	NS_TEMPLATE_TALK    => 'T6e_t2k',
	NS_HELP             => 'H2p',
	NS_HELP_TALK        => 'H2p_t2k',
	NS_CATEGORY         => 'C6y',
	NS_CATEGORY_TALK    => 'C6y_t2k',
];

/**
 * Array of namespace aliases, mapping from name to NS_xxx index.
 *
 * Note that 'namespaceAliases' is a mergable language attribute,
 * which means it is combined with other languages in the fallback chain.
 */
$namespaceAliases = [
	// The canonical names of namespaces 6 and 7 are, as of MediaWik 1.14,
	// "File" and "File_talk".  The old names "Image" and "Image_talk" are
	// retained as aliases for backwards compatibility.
	// This must apply regardless of site language (and does, given 'en' is at
	// the end of all fallback chains.)
	'I3e' => NS_FILE,
	'I3e_t2k' => NS_FILE_TALK,
];

/**
 * A list of date format preference keys, which can be selected in user
 * preferences. New preference keys can be added, provided they are supported
 * by the language class's timeanddate(). Only the 5 keys listed below are
 * supported by the wikitext converter (parser/DateFormatter.php).
 *
 * The special key "default" is an alias for either dmy or mdy depending on
 * $wgAmericanDates
 */
$datePreferences = [
	'default',
	'mdy',
	'dmy',
	'ymd',
	'ISO 8601',
	'yogurian',
];

/**
 * The date format to use for generated dates in the user interface.
 * This may be one of the above date preferences, or the special value
 * "dmy or mdy", which uses mdy if $wgAmericanDates is true, and dmy
 * if $wgAmericanDates is false.
 */
$defaultDateFormat = 'yogurian';

/**
 * Associative array mapping old numeric date formats, which may still be
 * stored in user preferences, to the new string formats.
 */
$datePreferenceMigrationMap = [
	'default',
	'mdy',
	'dmy',
	'ymd'
];

/**
 * These are formats for dates generated by MediaWiki (as opposed to the wikitext
 * DateFormatter). Documentation for the format string can be found in
 * Language.php, search for sprintfDate.
 *
 * This array is automatically inherited by all subclasses. Individual keys can be
 * overridden.
 */
$dateFormats = [
	'mdy time' => 'H:i',
	'mdy date' => 'F j, Y',
	'mdy monthonly' => 'F Y',
	'mdy both' => 'H:i, F j, Y',
	'mdy pretty' => 'F j',

	'dmy time' => 'H:i',
	'dmy date' => 'j F Y',
	'dmy monthonly' => 'F Y',
	'dmy both' => 'H:i, j F Y',
	'dmy pretty' => 'j F',

	'ymd time' => 'H:i',
	'ymd date' => 'Y F j',
	'ymd monthonly' => 'Y F',
	'ymd both' => 'H:i, Y F j',
	'ymd pretty' => 'F j',

	'ISO 8601 time' => 'xnH:xni:xns',
	'ISO 8601 date' => 'xnY-xnm-xnd',
	'ISO 8601 monthonly' => 'xnY-xnm',
	'ISO 8601 both' => 'xnY-xnm-xnd"T"xnH:xni:xns',
	'ISO 8601 pretty' => 'xnm-xnd',

	'yogurian time' => 'H:i',
	'yogurian date' => 'xyY \\Y2\\r xyn \\M3\\h xyj \\D2\\s (xyD)',
	'yogurian both' => 'xyY \\Y2\\r xyn \\M3\\h xyj \\D2\\s (xyD) H:i',
];

/**
 * Magic words
 * Customizable syntax for wikitext and elsewhere.
 *
 * IDs must be valid identifiers, they cannot contain hyphens.
 * CASE is 0 to match all case variants, 1 for case-sensitive
 *
 * Note to localisers:
 *   - Include the English magic words as synonyms. This allows people from
 *     other wikis that do not speak the language to contribute more easily.
 *   - The first alias listed MUST be the preferred alias in that language.
 *     Tools (like Visual Editor) are expected to use the first listed alias
 *     when editing or creating new content.
 *   - Order the other aliases so that common aliases occur before more rarely
 *     used aliases. The aliases SHOULD be sorted by the following convention:
 *     1. Local first, English last, then
 *     2. Most common first, least common last.
 */
$magicWords = [
#   ID                               CASE  SYNONYMS
	'redirect'                => [ 0, '#REDIRECT' ],
	'notoc'                   => [ 0, '__NOTOC__' ],
	'nogallery'               => [ 0, '__NOGALLERY__' ],
	'forcetoc'                => [ 0, '__FORCETOC__' ],
	'toc'                     => [ 0, '__TOC__' ],
	'noeditsection'           => [ 0, '__NOEDITSECTION__' ],
	'!'                       => [ 1, '!' ],
	'currentmonth'            => [ 1, 'CURRENTMONTH', 'CURRENTMONTH2' ],
	'currentmonth1'           => [ 1, 'CURRENTMONTH1' ],
	'currentmonthname'        => [ 1, 'CURRENTMONTHNAME' ],
	'currentmonthnamegen'     => [ 1, 'CURRENTMONTHNAMEGEN' ],
	'currentmonthabbrev'      => [ 1, 'CURRENTMONTHABBREV' ],
	'currentday'              => [ 1, 'CURRENTDAY' ],
	'currentday2'             => [ 1, 'CURRENTDAY2' ],
	'currentdayname'          => [ 1, 'CURRENTDAYNAME' ],
	'currentyear'             => [ 1, 'CURRENTYEAR' ],
	'currenttime'             => [ 1, 'CURRENTTIME' ],
	'currenthour'             => [ 1, 'CURRENTHOUR' ],
	'localmonth'              => [ 1, 'LOCALMONTH', 'LOCALMONTH2' ],
	'localmonth1'             => [ 1, 'LOCALMONTH1' ],
	'localmonthname'          => [ 1, 'LOCALMONTHNAME' ],
	'localmonthnamegen'       => [ 1, 'LOCALMONTHNAMEGEN' ],
	'localmonthabbrev'        => [ 1, 'LOCALMONTHABBREV' ],
	'localday'                => [ 1, 'LOCALDAY' ],
	'localday2'               => [ 1, 'LOCALDAY2' ],
	'localdayname'            => [ 1, 'LOCALDAYNAME' ],
	'localyear'               => [ 1, 'LOCALYEAR' ],
	'localtime'               => [ 1, 'LOCALTIME' ],
	'localhour'               => [ 1, 'LOCALHOUR' ],
	'numberofpages'           => [ 1, 'NUMBEROFPAGES' ],
	'numberofarticles'        => [ 1, 'NUMBEROFARTICLES' ],
	'numberoffiles'           => [ 1, 'NUMBEROFFILES' ],
	'numberofusers'           => [ 1, 'NUMBEROFUSERS' ],
	'numberofactiveusers'     => [ 1, 'NUMBEROFACTIVEUSERS' ],
	'numberofedits'           => [ 1, 'NUMBEROFEDITS' ],
	'pagename'                => [ 1, 'PAGENAME' ],
	'pagenamee'               => [ 1, 'PAGENAMEE' ],
	'namespace'               => [ 1, 'NAMESPACE' ],
	'namespacee'              => [ 1, 'NAMESPACEE' ],
	'namespacenumber'         => [ 1, 'NAMESPACENUMBER' ],
	'talkspace'               => [ 1, 'TALKSPACE' ],
	'talkspacee'              => [ 1, 'TALKSPACEE' ],
	'subjectspace'            => [ 1, 'SUBJECTSPACE', 'ARTICLESPACE' ],
	'subjectspacee'           => [ 1, 'SUBJECTSPACEE', 'ARTICLESPACEE' ],
	'fullpagename'            => [ 1, 'FULLPAGENAME' ],
	'fullpagenamee'           => [ 1, 'FULLPAGENAMEE' ],
	'subpagename'             => [ 1, 'SUBPAGENAME' ],
	'subpagenamee'            => [ 1, 'SUBPAGENAMEE' ],
	'rootpagename'            => [ 1, 'ROOTPAGENAME' ],
	'rootpagenamee'           => [ 1, 'ROOTPAGENAMEE' ],
	'basepagename'            => [ 1, 'BASEPAGENAME' ],
	'basepagenamee'           => [ 1, 'BASEPAGENAMEE' ],
	'talkpagename'            => [ 1, 'TALKPAGENAME' ],
	'talkpagenamee'           => [ 1, 'TALKPAGENAMEE' ],
	'subjectpagename'         => [ 1, 'SUBJECTPAGENAME', 'ARTICLEPAGENAME' ],
	'subjectpagenamee'        => [ 1, 'SUBJECTPAGENAMEE', 'ARTICLEPAGENAMEE' ],
	'msg'                     => [ 0, 'MSG:' ],
	'subst'                   => [ 0, 'SUBST:' ],
	'safesubst'               => [ 0, 'SAFESUBST:' ],
	'msgnw'                   => [ 0, 'MSGNW:' ],
	'img_thumbnail'           => [ 1, 'thumb', 'thumbnail' ],
	'img_manualthumb'         => [ 1, 'thumbnail=$1', 'thumb=$1' ],
	'img_right'               => [ 1, 'right' ],
	'img_left'                => [ 1, 'left' ],
	'img_none'                => [ 1, 'none' ],
	'img_width'               => [ 1, '$1px' ],
	'img_center'              => [ 1, 'center', 'centre' ],
	'img_framed'              => [ 1, 'frame', 'framed', 'enframed' ],
	'img_frameless'           => [ 1, 'frameless' ],
	'img_lang'                => [ 1, 'lang=$1' ],
	'img_page'                => [ 1, 'page=$1', 'page $1' ],
	'img_upright'             => [ 1, 'upright', 'upright=$1', 'upright $1' ],
	'img_border'              => [ 1, 'border' ],
	'img_baseline'            => [ 1, 'baseline' ],
	'img_sub'                 => [ 1, 'sub' ],
	'img_super'               => [ 1, 'super', 'sup' ],
	'img_top'                 => [ 1, 'top' ],
	'img_text_top'            => [ 1, 'text-top' ],
	'img_middle'              => [ 1, 'middle' ],
	'img_bottom'              => [ 1, 'bottom' ],
	'img_text_bottom'         => [ 1, 'text-bottom' ],
	'img_link'                => [ 1, 'link=$1' ],
	'img_alt'                 => [ 1, 'alt=$1' ],
	'img_class'               => [ 1, 'class=$1' ],
	'int'                     => [ 0, 'INT:' ],
	'sitename'                => [ 1, 'SITENAME' ],
	'ns'                      => [ 0, 'NS:' ],
	'nse'                     => [ 0, 'NSE:' ],
	'localurl'                => [ 0, 'LOCALURL:' ],
	'localurle'               => [ 0, 'LOCALURLE:' ],
	'articlepath'             => [ 0, 'ARTICLEPATH' ],
	'pageid'                  => [ 0, 'PAGEID' ],
	'server'                  => [ 0, 'SERVER' ],
	'servername'              => [ 0, 'SERVERNAME' ],
	'scriptpath'              => [ 0, 'SCRIPTPATH' ],
	'stylepath'               => [ 0, 'STYLEPATH' ],
	'grammar'                 => [ 0, 'GRAMMAR:' ],
	'gender'                  => [ 0, 'GENDER:' ],
	'bidi'                    => [ 0, 'BIDI:' ],
	'notitleconvert'          => [ 0, '__NOTITLECONVERT__', '__NOTC__' ],
	'nocontentconvert'        => [ 0, '__NOCONTENTCONVERT__', '__NOCC__' ],
	'currentweek'             => [ 1, 'CURRENTWEEK' ],
	'currentdow'              => [ 1, 'CURRENTDOW' ],
	'localweek'               => [ 1, 'LOCALWEEK' ],
	'localdow'                => [ 1, 'LOCALDOW' ],
	'revisionid'              => [ 1, 'REVISIONID' ],
	'revisionday'             => [ 1, 'REVISIONDAY' ],
	'revisionday2'            => [ 1, 'REVISIONDAY2' ],
	'revisionmonth'           => [ 1, 'REVISIONMONTH' ],
	'revisionmonth1'          => [ 1, 'REVISIONMONTH1' ],
	'revisionyear'            => [ 1, 'REVISIONYEAR' ],
	'revisiontimestamp'       => [ 1, 'REVISIONTIMESTAMP' ],
	'revisionuser'            => [ 1, 'REVISIONUSER' ],
	'revisionsize'            => [ 1, 'REVISIONSIZE' ],
	'plural'                  => [ 0, 'PLURAL:' ],
	'fullurl'                 => [ 0, 'FULLURL:' ],
	'fullurle'                => [ 0, 'FULLURLE:' ],
	'canonicalurl'            => [ 0, 'CANONICALURL:' ],
	'canonicalurle'           => [ 0, 'CANONICALURLE:' ],
	'lcfirst'                 => [ 0, 'LCFIRST:' ],
	'ucfirst'                 => [ 0, 'UCFIRST:' ],
	'lc'                      => [ 0, 'LC:' ],
	'uc'                      => [ 0, 'UC:' ],
	'raw'                     => [ 0, 'RAW:' ],
	'displaytitle'            => [ 1, 'DISPLAYTITLE' ],
	'rawsuffix'               => [ 1, 'R' ],
	'nocommafysuffix'         => [ 0, 'NOSEP' ],
	'newsectionlink'          => [ 1, '__NEWSECTIONLINK__' ],
	'nonewsectionlink'        => [ 1, '__NONEWSECTIONLINK__' ],
	'currentversion'          => [ 1, 'CURRENTVERSION' ],
	'urlencode'               => [ 0, 'URLENCODE:' ],
	'anchorencode'            => [ 0, 'ANCHORENCODE' ],
	'currenttimestamp'        => [ 1, 'CURRENTTIMESTAMP' ],
	'localtimestamp'          => [ 1, 'LOCALTIMESTAMP' ],
	'directionmark'           => [ 1, 'DIRECTIONMARK', 'DIRMARK' ],
	'language'                => [ 0, '#LANGUAGE:' ],
	'contentlanguage'         => [ 1, 'CONTENTLANGUAGE', 'CONTENTLANG' ],
	'pagelanguage'            => [ 1, 'PAGELANGUAGE' ],
	'pagesinnamespace'        => [ 1, 'PAGESINNAMESPACE:', 'PAGESINNS:' ],
	'numberofadmins'          => [ 1, 'NUMBEROFADMINS' ],
	'formatnum'               => [ 0, 'FORMATNUM' ],
	'padleft'                 => [ 0, 'PADLEFT' ],
	'padright'                => [ 0, 'PADRIGHT' ],
	'special'                 => [ 0, 'special' ],
	'speciale'                => [ 0, 'speciale' ],
	'defaultsort'             => [ 1, 'DEFAULTSORT:', 'DEFAULTSORTKEY:', 'DEFAULTCATEGORYSORT:' ],
	'filepath'                => [ 0, 'FILEPATH:' ],
	'tag'                     => [ 0, 'tag' ],
	'hiddencat'               => [ 1, '__HIDDENCAT__' ],
	'expectunusedcategory'    => [ 1, '__EXPECTUNUSEDCATEGORY__', ],
	'pagesincategory'         => [ 1, 'PAGESINCATEGORY', 'PAGESINCAT' ],
	'pagesize'                => [ 1, 'PAGESIZE' ],
	'index'                   => [ 1, '__INDEX__' ],
	'noindex'                 => [ 1, '__NOINDEX__' ],
	'numberingroup'           => [ 1, 'NUMBERINGROUP', 'NUMINGROUP' ],
	'staticredirect'          => [ 1, '__STATICREDIRECT__' ],
	'protectionlevel'         => [ 1, 'PROTECTIONLEVEL' ],
	'protectionexpiry'        => [ 1, 'PROTECTIONEXPIRY' ],
	'cascadingsources'        => [ 1, 'CASCADINGSOURCES' ],
	'formatdate'              => [ 0, 'formatdate', 'dateformat' ],
	'url_path'                => [ 0, 'PATH' ],
	'url_wiki'                => [ 0, 'WIKI' ],
	'url_query'               => [ 0, 'QUERY' ],
	'defaultsort_noerror'     => [ 0, 'noerror' ],
	'defaultsort_noreplace'   => [ 0, 'noreplace' ],
	'displaytitle_noerror'    => [ 0, 'noerror' ],
	'displaytitle_noreplace'  => [ 0, 'noreplace' ],
	'pagesincategory_all'     => [ 0, 'all' ],
	'pagesincategory_pages'   => [ 0, 'pages' ],
	'pagesincategory_subcats' => [ 0, 'subcats' ],
	'pagesincategory_files'   => [ 0, 'files' ],
];

/**
 * Alternate names of special pages. All names are case-insensitive. The first
 * listed alias will be used as the default. Aliases from the fallback
 * localisation (usually English) will be included by default.
 */
$specialPageAliases = [
	'Activeusers'               => [ 'A4eU3s' ],
	'Allmessages'               => [ 'A1lM6s' ],
	'AllMyUploads'              => [ 'A1lM0yU5s', 'A1lM0yF3s' ],
	'Allpages'                  => [ 'A1lP3s' ],
	'ApiHelp'                   => [ 'A1iH2p' ],
	'ApiSandbox'                => [ 'A1iS5x' ],
	'Ancientpages'              => [ 'A5tP3s' ],
	'AutoblockList'             => [ 'A7kL2t', 'L2tA8s' ],
	'Badtitle'                  => [ 'B6e' ],
	'Blankpage'                 => [ 'B3kP2e' ],
	'Block'                     => [ 'B3k', 'B3kI0P', 'B3kU2r' ],
	'BlockList'                 => [ 'B3kL2t', 'L2tB4s', 'I0PB3kL2t' ],
	'Booksources'               => [ 'B2kS5s' ],
	'BotPasswords'              => [ 'B1tP7s' ],
	'BrokenRedirects'           => [ 'B4nR7s' ],
	'Categories'                => [ 'C8s' ],
	'ChangeContentModel'        => [ 'C4eC5tM3l' ],
	'ChangeCredentials'         => [ 'C4eC9s' ],
	'ChangeEmail'               => [ 'C4eE3l' ],
	'ChangePassword'            => [ 'C4eP6d', 'R3tP2s', 'R3tP6d' ],
	'ComparePages'              => [ 'C5eP3s' ],
	'Confirmemail'              => [ 'C5mE3l' ],
	'Contributions'             => [ 'C11s', 'C6s' ],
	'CreateAccount'             => [ 'C4eA5t' ],
	'Deadendpages'              => [ 'D5dP3s' ],
	'DeletedContributions'      => [ 'D5dC11s' ],
	'Diff'                      => [ 'D2f' ],
	'DoubleRedirects'           => [ 'D4eR7s' ],
	'EditPage'                  => [ 'E2tP2e', 'E2t' ],
	'EditTags'                  => [ 'E2tT2s' ],
	'EditWatchlist'             => [ 'E2tW7t' ],
	'Emailuser'                 => [ 'E3lU2r', 'E3l' ],
	'ExpandTemplates'           => [ 'E4dT7s' ],
	'Export'                    => [ 'E4t' ],
	'Fewestrevisions'           => [ 'F4tR7s' ],
	'FileDuplicateSearch'       => [ 'F2eD7eS5h' ],
	'Filepath'                  => [ 'F2eP2h' ],
	'GoToInterwiki'             => [ 'G0oT0oI7i' ],
	'Import'                    => [ 'I4t' ],
	'Invalidateemail'           => [ 'I8eE3l' ],
	'JavaScriptTest'            => [ 'J2aS4tT2t' ],
	'LinkSearch'                => [ 'L2kS4h' ],
	'LinkAccounts'              => [ 'L2kA6s' ],
	'Listadmins'                => [ 'L2tA4s' ],
	'Listbots'                  => [ 'L2tB2s' ],
	'Listfiles'                 => [ 'L2tF3s', 'F2eL2t', 'I3eL2t' ],
	'Listgrouprights'           => [ 'L2tG3pR4s', 'U2rG3pR4s' ],
	'Listgrants'                => [ 'L2tG4s' ],
	'Listredirects'             => [ 'L2tR7s' ],
	'ListDuplicatedFiles'       => [ 'L2tD8dF3s', 'L2tF2eD8s' ],
	'Listusers'                 => [ 'L2tU3s', 'U2rL2t', 'U3s' ],
	'Lockdb'                    => [ 'L2kD0B' ],
	'Log'                       => [ 'L1g', 'L2s' ],
	'Lonelypages'               => [ 'L4yP3s', 'O6dP3s' ],
	'Longpages'                 => [ 'L2gP3s' ],
	'MediaStatistics'           => [ 'M3aS8s' ],
	'MergeHistory'              => [ 'M3eH5y' ],
	'MIMEsearch'                => [ 'M2ES4h' ],
	'Mostcategories'            => [ 'M2tC8s' ],
	'Mostimages'                => [ 'M2tL4dF3s', 'M2tF3s', 'M2tI4s' ],
	'Mostinterwikis'            => [ 'M2tI8s' ],
	'Mostlinked'                => [ 'M2tL4dP3s', 'M2tL4d' ],
	'Mostlinkedcategories'      => [ 'M2tL4dC8s', 'M2tU2dC8s' ],
	'Mostlinkedtemplates'       => [ 'M2tT9dP3s', 'M2tL4dT7s', 'M2tU2dT7s' ],
	'Mostrevisions'             => [ 'M2tR7s' ],
	'Movepage'                  => [ 'M2eP2e' ],
	'Mute'                      => [ 'M2e' ],
	'Mycontributions'           => [ 'M0yC11s' ],
	'MyLanguage'                => [ 'M0yL6e' ],
	'Mypage'                    => [ 'M0yP2e' ],
	'Mytalk'                    => [ 'M0yT2k' ],
	'Myuploads'                 => [ 'M0yU5s', 'M0yF3s' ],
	'Newimages'                 => [ 'N1wF3s', 'N1wI4s' ],
	'NewSection'                => [ 'N1wS5n', 'N8n' ],
	'Newpages'                  => [ 'N1wP3s' ],
	'PagesWithProp'             => [ 'P3sW2hP2p', 'P11p', 'P3sB0yP2p', 'P9p' ],
	'PageData'                  => [ 'P2eD2a' ],
	'PageHistory'               => [ 'P2eH5y', 'H5y' ],
	'PageInfo'                  => [ 'P2eI2o', 'I2o' ],
	'PageLanguage'              => [ 'P2eL6e' ],
	'PasswordPolicies'          => [ 'P6dP6s' ],
	'PasswordReset'             => [ 'P6dR3t' ],
	'PermanentLink'             => [ 'P7tL2k', 'P3aL2k' ],
	'Preferences'               => [ 'P9s' ],
	'Prefixindex'               => [ 'P4xI3x' ],
	'Protectedpages'            => [ 'P7dP3s' ],
	'Protectedtitles'           => [ 'P7dT4s' ],
	'Purge'                     => [ 'P3e' ],
	'Randompage'                => [ 'R4m', 'R4mP2e' ],
	'RandomInCategory'          => [ 'R4mI0nC6y' ],
	'Randomredirect'            => [ 'R4mR6t' ],
	'Randomrootpage'            => [ 'R4mR6e' ],
	'Recentchanges'             => [ 'R4tC5s' ],
	'Recentchangeslinked'       => [ 'R4tC5sL4d', 'R5dC5s' ],
	'Redirect'                  => [ 'R6t' ],
	'RemoveCredentials'         => [ 'R4eC9s' ],
	'ResetTokens'               => [ 'R3tT4s' ],
	'Revisiondelete'            => [ 'R6nD4e' ],
	'RunJobs'                   => [ 'R1nJ2s' ],
	'Search'                    => [ 'S4h' ],
	'Shortpages'                => [ 'S3tP3s' ],
	'Specialpages'              => [ 'S5lP3s' ],
	'Statistics'                => [ 'S8s', 'S3s' ],
	'Tags'                      => [ 'T2s' ],
	'TrackingCategories'        => [ 'T6gC8s' ],
	'Unblock'                   => [ 'U5k' ],
	'Uncategorizedcategories'   => [ 'U11dC8s' ],
	'Uncategorizedimages'       => [ 'U11dF3s', 'U11dI4s' ],
	'Uncategorizedpages'        => [ 'U11dP3s' ],
	'Uncategorizedtemplates'    => [ 'U11dT7s' ],
	'Undelete'                  => [ 'U6e' ],
	'UnlinkAccounts'            => [ 'U4kA6s' ],
	'Unlockdb'                  => [ 'U4kD0B' ],
	'Unusedcategories'          => [ 'U4dC8s' ],
	'Unusedimages'              => [ 'U4dF3s', 'U4dI4s' ],
	'Unusedtemplates'           => [ 'U4dT7s' ],
	'Unwatchedpages'            => [ 'U7dP3s' ],
	'Upload'                    => [ 'U4d' ],
	'UploadStash'               => [ 'U4dS3h' ],
	'Userlogin'                 => [ 'U2rL3n', 'L3n' ],
	'Userlogout'                => [ 'U2rL4t', 'L4t' ],
	'Userrights'                => [ 'U2rR4s', 'M2eS3p', 'M2eB1t' ],
	'Version'                   => [ 'V5n' ],
	'Wantedcategories'          => [ 'W4dC8s' ],
	'Wantedfiles'               => [ 'W4dF3s' ],
	'Wantedpages'               => [ 'W4dP3s', 'B4nL3s' ],
	'Wantedtemplates'           => [ 'W4dT7s' ],
	'Watchlist'                 => [ 'W7t' ],
	'Whatlinkshere'             => [ 'W2tL3sH2e' ],
	'Withoutinterwiki'          => [ 'W5tI7i' ],
];
